@@ -1,2 +1,2 @@
-from .LEAP import LeapForCausalLM, LeapConfig
+from .LEAP import LeapForCausalLM, LeapConfig, MultiheadLeap
 from .fastformerLM.fastformer import FastformerForCausalLM, FastformerLMConfig
\ No newline at end of file
